@@ -1,7 +1,7 @@
 package Yars::Routes;
 
 # ABSTRACT: set up the routes for Yars.
-our $VERSION = '0.91_02'; # VERSION
+our $VERSION = '0.97_01'; # VERSION
 
 
 use strict;
@@ -11,14 +11,27 @@ use Clustericious::Log;
 use File::Path qw/mkpath/;
 use File::Temp;
 use Clustericious::RouteBuilder;
-use Try::Tiny;
 use Data::Dumper;
-use Filesys::Df qw/df/;
+use if $^O ne 'MSWin32', 'Filesys::Df' => qw/df/;
 use List::Util qw/shuffle/;
 use List::MoreUtils qw/uniq/;
 use Digest::file qw/digest_file_hex/;
 use File::Basename qw/basename/;
 
+BEGIN {
+  if($^O eq 'MSWin32')
+  {
+    # Filesys::Df is not available for MSWin32,
+    # so we use Filesys::DfPortable on that platform
+    require Filesys::DfPortable;
+    *df = sub {
+      my $df = Filesys::DfPortable::dfportable(@_);
+      $df->{used} = $df->{bused};
+      $df;
+    };
+  }
+}
+
 
 get '/' => sub { shift->render_text("welcome to Yars") } => 'index';
 
@@ -282,11 +295,11 @@ sub _atomic_write {
     TRACE "Writing $dir/$filename";
     # Write a file atomically.  Return 1 on success, 0 on failure.
     my $failed;
-    try {
+    eval {
         mkpath $dir; # dies on error
         $asset->move_to("$dir/$filename") or LOGDIE "failed to write $dir/$filename: $!";
-    } catch {
-        WARN "Could not write $dir/$filename : $_";
+    }; if($@) {
+        WARN "Could not write $dir/$filename : $@";
         $failed = 1;
     };
     return 0 if $failed;
@@ -607,7 +620,7 @@ Yars::Routes - set up the routes for Yars.
 
 =head1 VERSION
 
-version 0.91_02
+version 0.97_01
 
 =head1 ROUTES
 
